@@ -130,7 +130,7 @@ has user_bnf_file =>
 
 # Warning: There's another $VERSION in package MarpaX::Grammar::Parser::Dummy below.
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 # ------------------------------------------------
 
@@ -239,7 +239,7 @@ sub _build_hashref
 
 } # End of _build_hashref.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _check_start_rule
 {
@@ -280,7 +280,7 @@ sub _check_start_rule
 
 } # End of _check_start_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub clean_name
 {
@@ -313,7 +313,7 @@ sub clean_name
 
 } # End of clean_name.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub compress_branch
 {
@@ -416,7 +416,7 @@ sub compress_branch
 
 } # End of compress_branch.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub compress_tree
 {
@@ -440,7 +440,7 @@ sub compress_tree
 
 } # End of compress_tree.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _fabricate_start_rule
 {
@@ -448,7 +448,7 @@ sub _fabricate_start_rule
 
 	# Add a start_rule sub-tree to the cooked tree.
 
-	my($start_rule) = Tree::DAG_Node -> new({name => 'start'});
+	my($start_rule) = Tree::DAG_Node -> new({name => ':start'});
 
 	$start_rule -> add_daughter(Tree::DAG_Node -> new({name => '::='}) );
 	$start_rule -> add_daughter(Tree::DAG_Node -> new({name => $self -> first_rule}) );
@@ -456,18 +456,17 @@ sub _fabricate_start_rule
 
 } # End of _fabricate_start_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
-sub _find_start_rule
+sub _find_first_rule
 {
 	my($self, $user_bnf) = @_;
 
 	for my $line (split(/\n/, $user_bnf) )
 	{
-		# We assume the rules all start (at least) on 1 line.
-		# The \w+ will ignore :default, :start, etc.
+		# Assume the rule name and the '::=' are on the same line.
 
-		if ($line =~ /^\s*(\w+)\s*::=\s*<?[\w]+>?$/)
+		if ($line =~ /^\s*(<?\w+>?)\s*::=/)
 		{
 			$self -> first_rule($1);
 
@@ -475,7 +474,7 @@ sub _find_start_rule
 		}
 	}
 
-} # End of _find_start_rule.
+} # End of _find_first_rule.
 
 # ------------------------------------------------
 
@@ -530,7 +529,7 @@ sub format_hashref
 
 } # End of format_hashref.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub log
 {
@@ -540,7 +539,7 @@ sub log
 
 } # End of log.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_completion_event_rule
 {
@@ -579,7 +578,7 @@ sub _process_completion_event_rule
 
 } # End of _process_completion_event_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_default_rule
 {
@@ -623,7 +622,7 @@ sub _process_default_rule
 
 } # End of _process_default_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_discard_rule
 {
@@ -658,7 +657,7 @@ sub _process_discard_rule
 
 } # End of _process_discard_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_empty_rule
 {
@@ -697,7 +696,7 @@ sub _process_empty_rule
 
 } # End of _process_empty_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_lexeme_default
 {
@@ -743,7 +742,7 @@ sub _process_lexeme_default
 
 } # End of _process_lexeme_default.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_lexeme_rule
 {
@@ -788,7 +787,7 @@ sub _process_lexeme_rule
 
 } # End of _process_lexeme_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_nulled_event_rule
 {
@@ -827,7 +826,7 @@ sub _process_nulled_event_rule
 
 } # End of _process_nulled_event_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_parenthesized_list
 {
@@ -865,7 +864,7 @@ sub _process_parenthesized_list
 
 } # End of _process_parenthesized_list.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_predicted_event_rule
 {
@@ -904,7 +903,7 @@ sub _process_predicted_event_rule
 
 } # End of _process_predicted_event_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_priority_rule
 {
@@ -985,7 +984,7 @@ sub _process_priority_rule
 
 } # End of _process_priority_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_quantified_rule
 {
@@ -1040,7 +1039,7 @@ sub _process_quantified_rule
 
 } # End of _process_quantified_rule.
 
-# --------------------------------------------------
+# ------------------------------------------------
 
 sub _process_start_rule
 {
@@ -1100,7 +1099,7 @@ sub run
 	my $user_bnf       = read_file($self -> user_bnf_file, binmode =>':utf8');
 	my($recce)         = Marpa::R2::Scanless::R -> new({grammar => $marpa_grammar});
 
-	$self -> _find_start_rule($user_bnf);
+	$self -> _find_first_rule($user_bnf);
 	$recce -> read(\$user_bnf);
 
 	my($value) = $recce -> value;
@@ -1166,7 +1165,7 @@ sub run
 
 package MarpaX::Grammar::Parser::Dummy;
 
-our $VERSION = '1.04';
+our $VERSION = '1.07';
 
 sub new{return {};}
 
